@@ -251,43 +251,43 @@
 #include "deque"
 // ./core/clingutils/G__listDict.cxx
 #include "list"
+// ./core/clingutils/G__forward_listDict.cxx
+#include "forward_list"
 // ./core/clingutils/G__multisetDict.cxx
 #include "set"
+// ./core/clingutils/G__vectorDict.cxx
+#include "vector"
 // ./core/clingutils/G__setDict.cxx
 #include "set"
 // ./core/clingutils/G__multimap2Dict.cxx
 #include "map"
-// ./core/clingutils/G__complexDict.cxx
-#include "root_std_complex.h"
-// ./core/clingutils/G__unordered_setDict.cxx
-#include "unordered_set"
 // ./core/clingutils/G__unordered_multisetDict.cxx
 #include "unordered_set"
-// ./core/clingutils/G__valarrayDict.cxx
-#include "valarray"
-// ./core/clingutils/G__map2Dict.cxx
-#include "map"
-// ./core/clingutils/G__forward_listDict.cxx
-#include "forward_list"
-// ./core/clingutils/G__vectorDict.cxx
-#include "vector"
+// ./core/clingutils/G__complexDict.cxx
+#include "root_std_complex.h"
 // ./core/clingutils/G__multimapDict.cxx
 #include "map"
+// ./core/clingutils/G__unordered_setDict.cxx
+#include "unordered_set"
+// ./core/clingutils/G__map2Dict.cxx
+#include "map"
 // ./core/clingutils/G__mapDict.cxx
 #include "map"
+// ./core/clingutils/G__valarrayDict.cxx
+#include "valarray"
 // ./core/clingutils/G__unordered_multimapDict.cxx
 #include "unordered_map"
 // ./core/clingutils/G__unordered_mapDict.cxx
 #include "unordered_map"
 // ./core/multiproc/G__MultiProc.cxx
-#include "TMPClient.h"
+#include "MPCode.h"
 #include "MPSendRecv.h"
-#include "ROOT/TProcessExecutor.hxx"
-#include "TProcPool.h"
+#include "PoolUtils.h"
+#include "TMPClient.h"
 #include "TMPWorker.h"
 #include "TMPWorkerExecutor.h"
-#include "MPCode.h"
-#include "PoolUtils.h"
+#include "TProcPool.h"
+#include "ROOT/TProcessExecutor.hxx"
 // ./core/rint/G__Rint.cxx
 #include "TRint.h"
 #include "TTabCom.h"
@@ -319,205 +319,6 @@
 #include "ROOT/TPoolManager.hxx"
 #include "ROOT/TTaskGroup.hxx"
 #include "ROOT/TThreadExecutor.hxx"
-// ./core/base/G__Core.cxx
-#include "Buttons.h"
-#include "Bytes.h"
-#include "Byteswap.h"
-#include "Gtypes.h"
-#include "GuiTypes.h"
-#include "KeySymbols.h"
-#include "MessageTypes.h"
-#include "ROOT/TExecutor.hxx"
-#include "ROOT/TSequentialExecutor.hxx"
-#include "Riostream.h"
-#include "Rtypes.h"
-#include "TApplication.h"
-#include "TApplicationImp.h"
-#include "TAtt3D.h"
-#include "TAttAxis.h"
-#include "TAttBBox.h"
-#include "TAttBBox2D.h"
-#include "TAttFill.h"
-#include "TAttLine.h"
-#include "TAttMarker.h"
-#include "TAttPad.h"
-#include "TAttText.h"
-#include "TBase64.h"
-#include "TBenchmark.h"
-#include "TBrowser.h"
-#include "TBrowserImp.h"
-#include "TBuffer.h"
-#include "TBuffer3D.h"
-#include "TBuffer3DTypes.h"
-#include "TCanvasImp.h"
-#include "TColor.h"
-#include "TColorGradient.h"
-#include "TContextMenu.h"
-#include "TContextMenuImp.h"
-#include "TControlBarImp.h"
-#include "TDatime.h"
-#include "TDirectory.h"
-#include "TEnv.h"
-#include "TError.h"
-#include "TException.h"
-#include "TExec.h"
-#include "TFileCollection.h"
-#include "TFileInfo.h"
-#include "TFolder.h"
-#include "TGuiFactory.h"
-#include "TInetAddress.h"
-#include "TInspectorImp.h"
-#include "TMD5.h"
-#include "TMacro.h"
-#include "TMathBase.h"
-#include "TMemberInspector.h"
-#include "TMessageHandler.h"
-#include "TNamed.h"
-#include "TNotifyLink.h"
-#include "TObjString.h"
-#include "TObject.h"
-#include "TObjectSpy.h"
-#include "TPRegexp.h"
-#include "TParameter.h"
-#include "TPluginManager.h"
-#include "TPoint.h"
-#include "TProcessID.h"
-#include "TProcessUUID.h"
-#include "TQClass.h"
-#include "TQCommand.h"
-#include "TQConnection.h"
-#include "TQObject.h"
-#include "TROOT.h"
-#include "TRedirectOutputGuard.h"
-#include "TRef.h"
-#include "TRefCnt.h"
-#include "TRegexp.h"
-#include "TRemoteObject.h"
-#include "TRootIOCtor.h"
-#include "TStopwatch.h"
-#include "TStorage.h"
-#include "TString.h"
-#include "TStringLong.h"
-#include "TStyle.h"
-#include "TSysEvtHandler.h"
-#include "TSystem.h"
-#include "TSystemDirectory.h"
-#include "TSystemFile.h"
-#include "TTask.h"
-#include "TThreadSlots.h"
-#include "TTime.h"
-#include "TTimeStamp.h"
-#include "TTimer.h"
-#include "TUUID.h"
-#include "TUri.h"
-#include "TUrl.h"
-#include "TVersionCheck.h"
-#include "TVirtualAuth.h"
-#include "TVirtualFFT.h"
-#include "TVirtualGL.h"
-#include "TVirtualMonitoring.h"
-#include "TVirtualMutex.h"
-#include "TVirtualPS.h"
-#include "TVirtualPad.h"
-#include "TVirtualPadEditor.h"
-#include "TVirtualPadPainter.h"
-#include "TVirtualPerfStats.h"
-#include "TVirtualQConnection.h"
-#include "TVirtualRWMutex.h"
-#include "TVirtualTableInterface.h"
-#include "TVirtualViewer3D.h"
-#include "TVirtualX.h"
-#include "ROOT/TLogger.hxx"
-#include "ROOT/RDrawable.hxx"
-#include "ROOT/TDirectoryEntry.hxx"
-#include "ROOT/TIndexIter.hxx"
-#include "strlcpy.h"
-#include "snprintf.h"
-#include "ROOT/TSeq.hxx"
-#include "TArray.h"
-#include "TArrayC.h"
-#include "TArrayD.h"
-#include "TArrayF.h"
-#include "TArrayI.h"
-#include "TArrayL.h"
-#include "TArrayL64.h"
-#include "TArrayS.h"
-#include "TBits.h"
-#include "TBtree.h"
-#include "TClassTable.h"
-#include "TClonesArray.h"
-#include "TCollection.h"
-#include "TCollectionProxyInfo.h"
-#include "TExMap.h"
-#include "THashList.h"
-#include "THashTable.h"
-#include "TIterator.h"
-#include "TList.h"
-#include "TMap.h"
-#include "TObjArray.h"
-#include "TObjectTable.h"
-#include "TOrdCollection.h"
-#include "TRefArray.h"
-#include "TRefTable.h"
-#include "TSeqCollection.h"
-#include "TSortedList.h"
-#include "TVirtualCollectionProxy.h"
-#include "ESTLType.h"
-#include "RStringView.h"
-#include "TClassEdit.h"
-#include "ROOT/RIntegerSequence.hxx"
-#include "ROOT/RMakeUnique.hxx"
-#include "ROOT/RNotFn.hxx"
-#include "ROOT/RSpan.hxx"
-#include "ROOT/RStringView.hxx"
-#include "ROOT/TypeTraits.hxx"
-#include "ROOT/span.hxx"
-#include "TUnixSystem.h"
-#include "TClingRuntime.h"
-#include "root_std_complex.h"
-#include "TBaseClass.h"
-#include "TClass.h"
-#include "TClassGenerator.h"
-#include "TClassMenuItem.h"
-#include "TClassRef.h"
-#include "TClassStreamer.h"
-#include "TDataMember.h"
-#include "TDataType.h"
-#include "TDictAttributeMap.h"
-#include "TDictionary.h"
-#include "TEnum.h"
-#include "TEnumConstant.h"
-#include "TFileMergeInfo.h"
-#include "TFunction.h"
-#include "TFunctionTemplate.h"
-#include "TGenericClassInfo.h"
-#include "TGlobal.h"
-#include "TInterpreter.h"
-#include "TInterpreterValue.h"
-#include "TIsAProxy.h"
-#include "TListOfDataMembers.h"
-#include "TListOfEnums.h"
-#include "TListOfEnumsWithLock.h"
-#include "TListOfFunctionTemplates.h"
-#include "TListOfFunctions.h"
-#include "TMemberStreamer.h"
-#include "TMethod.h"
-#include "TMethodArg.h"
-#include "TMethodCall.h"
-#include "TProtoClass.h"
-#include "TRealData.h"
-#include "TSchemaHelper.h"
-#include "TSchemaRule.h"
-#include "TSchemaRuleSet.h"
-#include "TStatusBitsChecker.h"
-#include "TStreamer.h"
-#include "TStreamerElement.h"
-#include "TToggle.h"
-#include "TToggleGroup.h"
-#include "TVirtualIsAProxy.h"
-#include "TVirtualRefProxy.h"
-#include "TVirtualStreamerInfo.h"
-#include "Getline.h"
 // ./math/mathcore/G__MathCore.cxx
 #include "Fit/BasicFCN.h"
 #include "Fit/BinData.h"
@@ -608,6 +409,7 @@
 #include "TRandom3.h"
 #include "TRandomGen.h"
 #include "TStatistic.h"
+#include "VectorizedTMath.h"
 // ./math/mathmore/G__MathMore.cxx
 #include "Math/ChebyshevApprox.h"
 #include "Math/Derivator.h"
@@ -824,10 +626,27 @@
 #include "Math/SMatrixFfwd.h"
 #include "Math/SVector.h"
 // ./math/smatrix/G__Smatrix.cxx
-#include "Math/SMatrix.h"
+#include "Math/BinaryOperators.h"
+#include "Math/BinaryOpPolicy.h"
+#include "Math/CholeskyDecomp.h"
+#include "Math/Dfact.h"
+#include "Math/Dfactir.h"
+#include "Math/Dfinv.h"
+#include "Math/Dinv.h"
+#include "Math/Dsfact.h"
+#include "Math/Dsinv.h"
+#include "Math/Expression.h"
+#include "Math/Functions.h"
+#include "Math/HelperOps.h"
+#include "Math/MatrixFunctions.h"
+#include "Math/MatrixRepresentationsStatic.h"
+#include "Math/MConfig.h"
 #include "Math/SMatrixDfwd.h"
 #include "Math/SMatrixFfwd.h"
+#include "Math/SMatrix.h"
+#include "Math/StaticCheck.h"
 #include "Math/SVector.h"
+#include "Math/UnaryOperators.h"
 // ./math/genvector/G__GenVector32.cxx
 #include "Math/Point2D.h"
 #include "Math/Point3D.h"
@@ -959,10 +778,10 @@
 #include "TBinomialEfficiencyFitter.h"
 #include "TConfidenceLevel.h"
 #include "TEfficiency.h"
-#include "TF1.h"
 #include "TF12.h"
 #include "TF1AbsComposition.h"
 #include "TF1Convolution.h"
+#include "TF1.h"
 #include "TF1NormSum.h"
 #include "TF2.h"
 #include "TF3.h"
@@ -970,57 +789,57 @@
 #include "TFitResultPtr.h"
 #include "TFormula.h"
 #include "TFractionFitter.h"
-#include "TGraph.h"
-#include "TGraph2D.h"
 #include "TGraph2DErrors.h"
+#include "TGraph2D.h"
 #include "TGraphAsymmErrors.h"
 #include "TGraphBentErrors.h"
-#include "TGraphDelaunay.h"
 #include "TGraphDelaunay2D.h"
+#include "TGraphDelaunay.h"
 #include "TGraphErrors.h"
+#include "TGraph.h"
 #include "TGraphSmooth.h"
 #include "TGraphTime.h"
-#include "TH1.h"
 #include "TH1C.h"
 #include "TH1D.h"
 #include "TH1F.h"
+#include "TH1.h"
 #include "TH1I.h"
 #include "TH1K.h"
 #include "TH1S.h"
-#include "TH2.h"
 #include "TH2C.h"
 #include "TH2D.h"
 #include "TH2F.h"
+#include "TH2.h"
 #include "TH2I.h"
 #include "TH2Poly.h"
 #include "TH2S.h"
-#include "TH3.h"
 #include "TH3C.h"
 #include "TH3D.h"
 #include "TH3F.h"
+#include "TH3.h"
 #include "TH3I.h"
 #include "TH3S.h"
 #include "THLimitsFinder.h"
-#include "THStack.h"
-#include "THn.h"
 #include "THnBase.h"
 #include "THnChain.h"
+#include "THn.h"
 #include "THnSparse.h"
 #include "THnSparse_Internal.h"
+#include "THStack.h"
 #include "TKDE.h"
-#include "TLimit.h"
 #include "TLimitDataSource.h"
+#include "TLimit.h"
 #include "TMultiDimFit.h"
 #include "TMultiGraph.h"
 #include "TNDArray.h"
 #include "TPolyMarker.h"
 #include "TPrincipal.h"
-#include "TProfile.h"
 #include "TProfile2D.h"
 #include "TProfile2Poly.h"
 #include "TProfile3D.h"
-#include "TSVDUnfold.h"
+#include "TProfile.h"
 #include "TSpline.h"
+#include "TSVDUnfold.h"
 #include "TVirtualFitter.h"
 #include "TVirtualGraphPainter.h"
 #include "TVirtualHistPainter.h"
@@ -1096,8 +915,10 @@
 #include "TLeafB.h"
 #include "TLeafC.h"
 #include "TLeafD.h"
+#include "TLeafD32.h"
 #include "TLeafElement.h"
 #include "TLeafF.h"
+#include "TLeafF16.h"
 #include "TLeaf.h"
 #include "TLeafI.h"
 #include "TLeafL.h"
@@ -1121,7 +942,10 @@
 #include "TVirtualIndex.h"
 #include "TVirtualTreePlayer.h"
 #include "ROOT/TIOFeatures.hxx"
+#include "ROOT/TBulkBranchRead.hxx"
 // ./tree/treeplayer/G__TreePlayer.cxx
+#include "ROOT/TTreeReaderFast.hxx"
+#include "ROOT/TTreeReaderValueFast.hxx"
 #include "TBranchProxyClassDescriptor.h"
 #include "TBranchProxyDescriptor.h"
 #include "TBranchProxyDirector.h"
@@ -1204,8 +1028,25 @@
 #include "ROOT/RDF/RRange.hxx"
 #include "ROOT/RDF/RSlotStack.hxx"
 #include "ROOT/RDF/Utils.hxx"
-#include "ROOT/RDF/TTreeAsFlatMatrix.hxx"
+#include "ROOT/RDF/PyROOTHelpers.hxx"
 #include "ROOT/RSqliteDS.hxx"
+#include "ROOT/RNTupleDS.hxx"
+// ./tree/ntuple/G__ROOTNTuple.cxx
+#include "ROOT/RColumn.hxx"
+#include "ROOT/RColumnElement.hxx"
+#include "ROOT/RColumnModel.hxx"
+#include "ROOT/REntry.hxx"
+#include "ROOT/RField.hxx"
+#include "ROOT/RFieldValue.hxx"
+#include "ROOT/RNTuple.hxx"
+#include "ROOT/RNTupleDescriptor.hxx"
+#include "ROOT/RNTupleModel.hxx"
+#include "ROOT/RNTupleUtil.hxx"
+#include "ROOT/RNTupleView.hxx"
+#include "ROOT/RPage.hxx"
+#include "ROOT/RPagePool.hxx"
+#include "ROOT/RPageStorage.hxx"
+#include "ROOT/RPageStorageRoot.hxx"
 // ./io/io/G__RIO.cxx
 #include "ROOT/TBufferMerger.hxx"
 #include "TArchiveFile.h"
@@ -1260,8 +1101,6 @@
 #include "TParallelMergingFile.h"
 #include "TPServerSocket.h"
 #include "TPSocket.h"
-#include "TS3HTTPRequest.h"
-#include "TS3WebFile.h"
 #include "TSecContext.h"
 #include "TServerSocket.h"
 #include "TSocket.h"
@@ -1272,9 +1111,11 @@
 #include "TSQLServer.h"
 #include "TSQLStatement.h"
 #include "TSQLTableInfo.h"
-#include "TSSLSocket.h"
 #include "TUDPSocket.h"
 #include "TWebFile.h"
+#include "TSSLSocket.h"
+#include "TS3HTTPRequest.h"
+#include "TS3WebFile.h"
 // ./net/netx/G__Netx.cxx
 #include "TXNetFile.h"
 #include "TXNetFileStager.h"
@@ -1285,24 +1126,27 @@
 #include "TNetXNGSystem.h"
 // ./graf2d/primitives/G__ROOTGraphicsPrimitives.cxx
 #include "ROOT/RBox.hxx"
-#include "ROOT/RColor.hxx"
-#include "ROOT/RDisplayItem.hxx"
-#include "ROOT/RDrawingAttr.hxx"
-#include "ROOT/RDrawingOptsBase.hxx"
 #include "ROOT/RLine.hxx"
 #include "ROOT/RMarker.hxx"
-#include "ROOT/RPalette.hxx"
-#include "ROOT/RStringEnumAttr.hxx"
-#include "ROOT/RStyle.hxx"
 #include "ROOT/RText.hxx"
 // ./graf2d/gpadv7/G__ROOTGpadv7.cxx
 #include "ROOT/RCanvas.hxx"
 #include "ROOT/RFrame.hxx"
 #include "ROOT/RMenuItem.hxx"
 #include "ROOT/RObjectDrawable.hxx"
-#include "ROOT/RPad.hxx"
+#include "ROOT/RColor.hxx"
+#include "ROOT/RDisplayItem.hxx"
+#include "ROOT/RDrawingAttr.hxx"
+#include "ROOT/RAttrBox.hxx"
+#include "ROOT/RAttrLine.hxx"
+#include "ROOT/RAttrMarker.hxx"
+#include "ROOT/RAttrText.hxx"
+#include "ROOT/RDrawingOptsBase.hxx"
+#include "ROOT/RPalette.hxx"
+#include "ROOT/RStyle.hxx"
 #include "ROOT/RPadDisplayItem.hxx"
 #include "ROOT/RPadExtent.hxx"
+#include "ROOT/RPad.hxx"
 #include "ROOT/RPadLength.hxx"
 #include "ROOT/RPadPainter.hxx"
 #include "ROOT/RPadPos.hxx"
@@ -1314,8 +1158,8 @@
 #include "TCanvas.h"
 #include "TClassTree.h"
 #include "TColorWheel.h"
-#include "TControlBar.h"
 #include "TControlBarButton.h"
+#include "TControlBar.h"
 #include "TCreatePrimitives.h"
 #include "TDialogCanvas.h"
 #include "TGroupButton.h"
@@ -1324,10 +1168,10 @@
 #include "TPadPainter.h"
 #include "TPaveClass.h"
 #include "TRatioPlot.h"
-#include "TSlider.h"
 #include "TSliderBox.h"
-#include "TView.h"
+#include "TSlider.h"
 #include "TViewer3DPad.h"
+#include "TView.h"
 // ./graf2d/graf/G__Graf.cxx
 #include "TArc.h"
 #include "TArrow.h"
@@ -1382,6 +1226,10 @@
 #include "TASPluginGS.h"
 // ./graf2d/asimage/G__ASImageGui.cxx
 #include "TASPaletteEditor.h"
+// ./graf2d/gviz/G__Gviz.cxx
+#include "TGraphEdge.h"
+#include "TGraphNode.h"
+#include "TGraphStruct.h"
 // ./graf2d/fitsio/G__FITSIO.cxx
 #include "TFITS.h"
 // ./graf3d/g3d/G__Graf3d.cxx
@@ -1391,25 +1239,25 @@
 #include "TCONS.h"
 #include "TCTUB.h"
 #include "TELTU.h"
-#include "TGTRA.h"
 #include "TGeometry.h"
-#include "THYPE.h"
+#include "TGTRA.h"
 #include "THelix.h"
+#include "THYPE.h"
 #include "TMarker3DBox.h"
 #include "TMaterial.h"
 #include "TMixture.h"
-#include "TNode.h"
 #include "TNodeDiv.h"
+#include "TNode.h"
 #include "TPARA.h"
 #include "TPCON.h"
 #include "TPGON.h"
-#include "TPointSet3D.h"
 #include "TPoints3DABC.h"
+#include "TPointSet3D.h"
 #include "TPolyLine3D.h"
 #include "TPolyMarker3D.h"
 #include "TRotMatrix.h"
-#include "TSPHE.h"
 #include "TShape.h"
+#include "TSPHE.h"
 #include "TTRAP.h"
 #include "TTRD1.h"
 #include "TTRD2.h"
@@ -1421,8 +1269,8 @@
 // ./graf3d/gl/G__RGL.cxx
 #include "TArcBall.h"
 #include "TF2GL.h"
-#include "TGL5D.h"
 #include "TGL5DDataSetEditor.h"
+#include "TGL5D.h"
 #include "TGLAdapter.h"
 #include "TGLAnnotation.h"
 #include "TGLAutoRotator.h"
@@ -1430,8 +1278,8 @@
 #include "TGLAxisPainter.h"
 #include "TGLBoundingBox.h"
 #include "TGLBoxPainter.h"
-#include "TGLCamera.h"
 #include "TGLCameraGuide.h"
+#include "TGLCamera.h"
 #include "TGLCameraOverlay.h"
 #include "TGLClip.h"
 #include "TGLClipSetEditor.h"
@@ -1439,15 +1287,15 @@
 #include "TGLCylinder.h"
 #include "TGLEmbeddedViewer.h"
 #include "TGLEventHandler.h"
-#include "TGLFBO.h"
 #include "TGLFaceSet.h"
+#include "TGLFBO.h"
 #include "TGLFontManager.h"
 #include "TGLFormat.h"
 #include "TGLH2PolyPainter.h"
 #include "TGLHistPainter.h"
 #include "TGLLegoPainter.h"
-#include "TGLLightSet.h"
 #include "TGLLightSetEditor.h"
+#include "TGLLightSet.h"
 #include "TGLLockable.h"
 #include "TGLLogicalShape.h"
 #include "TGLManip.h"
@@ -1455,15 +1303,12 @@
 #include "TGLObject.h"
 #include "TGLOrthoCamera.h"
 #include "TGLOutput.h"
-#include "TGLOverlay.h"
 #include "TGLOverlayButton.h"
-#include "TGLPShapeObj.h"
-#include "TGLPShapeObjEditor.h"
-#include "TGLPShapeRef.h"
+#include "TGLOverlay.h"
 #include "TGLPadPainter.h"
 #include "TGLPadUtils.h"
-#include "TGLParametric.h"
 #include "TGLParametricEquationGL.h"
+#include "TGLParametric.h"
 #include "TGLPerspectiveCamera.h"
 #include "TGLPhysicalShape.h"
 #include "TGLPlot3D.h"
@@ -1472,14 +1317,17 @@
 #include "TGLPlotPainter.h"
 #include "TGLPolyLine.h"
 #include "TGLPolyMarker.h"
+#include "TGLPShapeObjEditor.h"
+#include "TGLPShapeObj.h"
+#include "TGLPShapeRef.h"
 #include "TGLQuadric.h"
 #include "TGLRnrCtx.h"
 #include "TGLRotateManip.h"
 #include "TGLSAFrame.h"
 #include "TGLSAViewer.h"
 #include "TGLScaleManip.h"
-#include "TGLScene.h"
 #include "TGLSceneBase.h"
+#include "TGLScene.h"
 #include "TGLSceneInfo.h"
 #include "TGLScenePad.h"
 #include "TGLSelectBuffer.h"
@@ -1487,14 +1335,14 @@
 #include "TGLSphere.h"
 #include "TGLStopwatch.h"
 #include "TGLSurfacePainter.h"
+#include "TGLText.h"
 #include "TGLTF3Painter.h"
 #include "TGLTH3Composition.h"
-#include "TGLText.h"
 #include "TGLTransManip.h"
 #include "TGLUtil.h"
-#include "TGLViewer.h"
 #include "TGLViewerBase.h"
 #include "TGLViewerEditor.h"
+#include "TGLViewer.h"
 #include "TGLVoxelPainter.h"
 #include "TGLWidget.h"
 #include "TH2GL.h"
@@ -1502,99 +1350,100 @@
 #include "TPointSet3DGL.h"
 #include "TX11GL.h"
 // ./gui/gui/G__Gui.cxx
-#include "TGObject.h"
-#include "TGClient.h"
-#include "TGWindow.h"
-#include "TGPicture.h"
-#include "TGDimension.h"
-#include "TGFrame.h"
-#include "TGLayout.h"
-#include "TGString.h"
-#include "TGWidget.h"
-#include "TGIcon.h"
-#include "TGLabel.h"
-#include "TGButton.h"
-#include "TGTextBuffer.h"
-#include "TGTextEntry.h"
-#include "TGMsgBox.h"
-#include "TGMenu.h"
-#include "TGGC.h"
-#include "TGShutter.h"
+#include "HelpText.h"
 #include "TG3DLine.h"
-#include "TGProgressBar.h"
-#include "TGButtonGroup.h"
-#include "TGNumberEntry.h"
-#include "TGTableLayout.h"
-#include "WidgetMessageTypes.h"
-#include "TGIdleHandler.h"
-#include "TGInputDialog.h"
-#include "TGPack.h"
-#include "TGScrollBar.h"
-#include "TGCanvas.h"
-#include "TGListBox.h"
-#include "TGComboBox.h"
-#include "TGTab.h"
-#include "TGSlider.h"
-#include "TGListView.h"
-#include "TGMimeTypes.h"
-#include "TGFSContainer.h"
-#include "TGFileDialog.h"
-#include "TGStatusBar.h"
-#include "TGToolTip.h"
-#include "TGToolBar.h"
-#include "TGListTree.h"
-#include "TGText.h"
-#include "TGView.h"
-#include "TGTextView.h"
-#include "TGTextEdit.h"
-#include "TGTextEditDialogs.h"
-#include "TGDoubleSlider.h"
-#include "TGSplitter.h"
-#include "TGFSComboBox.h"
-#include "TGImageMap.h"
 #include "TGApplication.h"
-#include "TGXYLayout.h"
-#include "TGResourcePool.h"
-#include "TGFont.h"
-#include "TGTripleSlider.h"
-#include "TRootGuiFactory.h"
-#include "TRootApplication.h"
-#include "TRootCanvas.h"
-#include "TRootBrowserLite.h"
-#include "TRootContextMenu.h"
-#include "TRootDialog.h"
-#include "TRootControlBar.h"
-#include "TRootHelpDialog.h"
-#include "TRootEmbeddedCanvas.h"
+#include "TGButton.h"
+#include "TGButtonGroup.h"
+#include "TGCanvas.h"
+#include "TGClient.h"
 #include "TGColorDialog.h"
 #include "TGColorSelect.h"
-#include "TGFontDialog.h"
+#include "TGComboBox.h"
+#include "TGCommandPlugin.h"
+#include "TGDNDManager.h"
+#include "TGDimension.h"
 #include "TGDockableFrame.h"
+#include "TGDoubleSlider.h"
+#include "TGEventHandler.h"
+#include "TGFSComboBox.h"
+#include "TGFSContainer.h"
+#include "TGFileBrowser.h"
+#include "TGFileDialog.h"
+#include "TGFont.h"
+#include "TGFontDialog.h"
+#include "TGFrame.h"
+#include "TGGC.h"
+#include "TGIcon.h"
+#include "TGIdleHandler.h"
+#include "TGImageMap.h"
+#include "TGInputDialog.h"
+#include "TGLabel.h"
+#include "TGLayout.h"
+#include "TGListBox.h"
+#include "TGListTree.h"
+#include "TGListView.h"
 #include "TGMdi.h"
+#include "TGMdiDecorFrame.h"
 #include "TGMdiFrame.h"
 #include "TGMdiMainFrame.h"
-#include "TGMdiDecorFrame.h"
 #include "TGMdiMenu.h"
-#include "TVirtualDragManager.h"
-#include "TGuiBuilder.h"
-#include "TGRedirectOutputGuard.h"
+#include "TGMenu.h"
+#include "TGMimeTypes.h"
+#include "TGMsgBox.h"
+#include "TGNumberEntry.h"
+#include "TGObject.h"
+#include "TGPack.h"
 #include "TGPasswdDialog.h"
-#include "TGTextEditor.h"
-#include "TGSpeedo.h"
-#include "TGDNDManager.h"
-#include "TGTable.h"
-#include "TGSimpleTableInterface.h"
-#include "TGSimpleTable.h"
-#include "TGTableCell.h"
-#include "TGTableHeader.h"
-#include "TGTableContainer.h"
-#include "TGCommandPlugin.h"
-#include "TGFileBrowser.h"
-#include "TRootBrowser.h"
-#include "TGSplitFrame.h"
+#include "TGPicture.h"
+#include "TGProgressBar.h"
+#include "TGRedirectOutputGuard.h"
+#include "TGResourcePool.h"
+#include "TGScrollBar.h"
 #include "TGShapedFrame.h"
-#include "TGEventHandler.h"
+#include "TGShutter.h"
+#include "TGSimpleTable.h"
+#include "TGSimpleTableInterface.h"
+#include "TGSlider.h"
+#include "TGSpeedo.h"
+#include "TGSplitFrame.h"
+#include "TGSplitter.h"
+#include "TGStatusBar.h"
+#include "TGString.h"
+#include "TGTab.h"
+#include "TGTable.h"
+#include "TGTableCell.h"
+#include "TGTableContainer.h"
+#include "TGTableHeader.h"
+#include "TGTableLayout.h"
+#include "TGText.h"
+#include "TGTextBuffer.h"
+#include "TGTextEdit.h"
+#include "TGTextEditDialogs.h"
+#include "TGTextEditor.h"
+#include "TGTextEntry.h"
+#include "TGTextView.h"
 #include "TGTextViewStream.h"
+#include "TGToolBar.h"
+#include "TGToolTip.h"
+#include "TGTripleSlider.h"
+#include "TGView.h"
+#include "TGWidget.h"
+#include "TGWindow.h"
+#include "TGXYLayout.h"
+#include "TGuiBuilder.h"
+#include "TRootApplication.h"
+#include "TRootBrowser.h"
+#include "TRootBrowserLite.h"
+#include "TRootCanvas.h"
+#include "TRootContextMenu.h"
+#include "TRootControlBar.h"
+#include "TRootDialog.h"
+#include "TRootEmbeddedCanvas.h"
+#include "TRootGuiFactory.h"
+#include "TRootHelpDialog.h"
+#include "TVirtualDragManager.h"
+#include "WidgetMessageTypes.h"
 // ./gui/fitpanel/G__FitPanel.cxx
 #include "TAdvancedGraphicsDialog.h"
 #include "TFitEditor.h"
@@ -1602,6 +1451,7 @@
 #include "TTreeInput.h"
 // ./gui/fitpanelv7/G__ROOTFitPanelv7.cxx
 #include "ROOT/RFitPanel.hxx"
+#include "ROOT/RFitPanelModel.hxx"
 // ./bindings/pyroot/G__PyROOT.cxx
 #include "TPyArg.h"
 #include "TPyDispatcher.h"
@@ -1639,6 +1489,7 @@
 #include "TMVA/Envelope.h"
 #include "TMVA/Event.h"
 #include "TMVA/ExpectedErrorPruneTool.h"
+#include "TMVA/Executor.h"
 #include "TMVA/Factory.h"
 #include "TMVA/FitterBase.h"
 #include "TMVA/GeneticAlgorithm.h"
@@ -1775,47 +1626,47 @@
 #include "TMVA/Version.h"
 #include "TMVA/Volume.h"
 // ./tmva/tmvagui/G__TMVAGui.cxx
-#include "TMVA/annconvergencetest.h"
-#include "TMVA/deviations.h"
-#include "TMVA/mvaeffs.h"
-#include "TMVA/PlotFoams.h"
-#include "TMVA/TMVAGui.h"
-#include "TMVA/BDTControlPlots.h"
-#include "TMVA/correlationscatters.h"
-#include "TMVA/efficiencies.h"
-#include "TMVA/efficienciesMulticlass.h"
-#include "TMVA/mvas.h"
-#include "TMVA/probas.h"
 #include "TMVA/BDT.h"
-#include "TMVA/correlationscattersMultiClass.h"
-#include "TMVA/likelihoodrefs.h"
-#include "TMVA/mvasMulticlass.h"
-#include "TMVA/regression_averagedevs.h"
-#include "TMVA/TMVAMultiClassGui.h"
+#include "TMVA/BDTControlPlots.h"
 #include "TMVA/BDT_Reg.h"
-#include "TMVA/correlations.h"
-#include "TMVA/mvaweights.h"
-#include "TMVA/rulevisCorr.h"
-#include "TMVA/TMVARegGui.h"
 #include "TMVA/BoostControlPlots.h"
-#include "TMVA/correlationsMultiClass.h"
-#include "TMVA/network.h"
-#include "TMVA/rulevis.h"
-#include "TMVA/variables.h"
 #include "TMVA/CorrGui.h"
-#include "TMVA/paracoor.h"
-#include "TMVA/rulevisHists.h"
-#include "TMVA/variablesMultiClass.h"
-#include "TMVA/compareanapp.h"
 #include "TMVA/CorrGuiMultiClass.h"
 #include "TMVA/MovieMaker.h"
+#include "TMVA/PlotFoams.h"
+#include "TMVA/TMVAGui.h"
+#include "TMVA/TMVAMultiClassGui.h"
+#include "TMVA/TMVARegGui.h"
+#include "TMVA/annconvergencetest.h"
+#include "TMVA/compareanapp.h"
+#include "TMVA/correlations.h"
+#include "TMVA/correlationsMultiClass.h"
+#include "TMVA/correlationscatters.h"
+#include "TMVA/correlationscattersMultiClass.h"
+#include "TMVA/deviations.h"
+#include "TMVA/efficiencies.h"
+#include "TMVA/efficienciesMulticlass.h"
+#include "TMVA/likelihoodrefs.h"
+#include "TMVA/mvaeffs.h"
+#include "TMVA/mvas.h"
+#include "TMVA/mvasMulticlass.h"
+#include "TMVA/mvaweights.h"
+#include "TMVA/network.h"
+#include "TMVA/paracoor.h"
+#include "TMVA/probas.h"
+#include "TMVA/regression_averagedevs.h"
+#include "TMVA/rulevis.h"
+#include "TMVA/rulevisCorr.h"
+#include "TMVA/rulevisHists.h"
 #include "TMVA/tmvaglob.h"
+#include "TMVA/variables.h"
+#include "TMVA/variablesMultiClass.h"
 // ./tmva/pymva/G__PyMVA.cxx
-#include "TMVA/PyMethodBase.h"
-#include "TMVA/MethodPyRandomForest.h"
 #include "TMVA/MethodPyAdaBoost.h"
 #include "TMVA/MethodPyGTB.h"
 #include "TMVA/MethodPyKeras.h"
+#include "TMVA/MethodPyRandomForest.h"
+#include "TMVA/PyMethodBase.h"
 // ./roofit/roofitcore/G__RooFitCore.cxx
 #include "Roo1DTable.h"
 #include "RooAbsAnaConvPdf.h"
@@ -1999,6 +1850,7 @@
 #include "RooRealVarSharedProperties.h"
 #include "RooRecursiveFraction.h"
 #include "RooRefCountList.h"
+#include "RooSTLRefCountList.h"
 #include "RooResolutionModel.h"
 #include "RooScaledFunc.h"
 #include "RooSecondMoment.h"
@@ -2032,7 +1884,9 @@
 #include "RooUnitTest.h"
 #include "RooVectorDataStore.h"
 #include "RooWorkspace.h"
+#include "RooWorkspaceHandle.h"
 #include "RooXYChi2Var.h"
+#include "RooHelpers.h"
 // ./roofit/roofit/G__RooFit.cxx
 #include "Roo2DKeysPdf.h"
 #include "RooArgusBG.h"
@@ -2095,6 +1949,7 @@
 #include "RooUnblindUniform.h"
 #include "RooUniform.h"
 #include "RooVoigtian.h"
+#include "RooJohnson.h"
 // ./roofit/roostats/G__RooStats.cxx
 #include "RooStats/AsymptoticCalculator.h"
 #include "RooStats/BayesianCalculator.h"
@@ -2182,6 +2037,206 @@
 #include "RooStats/HistFactory/RooBarlowBeestonLL.h"
 #include "RooStats/HistFactory/Sample.h"
 #include "RooStats/HistFactory/Systematics.h"
+// ./core/G__Core.cxx
+#include "ROOT/StringConv.hxx"
+#include "ROOT/TExecutor.hxx"
+#include "ROOT/TSequentialExecutor.hxx"
+#include "Buttons.h"
+#include "Bytes.h"
+#include "Byteswap.h"
+#include "Gtypes.h"
+#include "GuiTypes.h"
+#include "KeySymbols.h"
+#include "MessageTypes.h"
+#include "Riostream.h"
+#include "Rtypes.h"
+#include "TApplication.h"
+#include "TApplicationImp.h"
+#include "TAtt3D.h"
+#include "TAttAxis.h"
+#include "TAttBBox2D.h"
+#include "TAttBBox.h"
+#include "TAttFill.h"
+#include "TAttLine.h"
+#include "TAttMarker.h"
+#include "TAttPad.h"
+#include "TAttText.h"
+#include "TBase64.h"
+#include "TBenchmark.h"
+#include "TBrowser.h"
+#include "TBrowserImp.h"
+#include "TBuffer3D.h"
+#include "TBuffer3DTypes.h"
+#include "TBuffer.h"
+#include "TCanvasImp.h"
+#include "TColorGradient.h"
+#include "TColor.h"
+#include "TContextMenu.h"
+#include "TContextMenuImp.h"
+#include "TControlBarImp.h"
+#include "TDatime.h"
+#include "TDirectory.h"
+#include "TEnv.h"
+#include "TError.h"
+#include "TException.h"
+#include "TExec.h"
+#include "TFileCollection.h"
+#include "TFileInfo.h"
+#include "TFolder.h"
+#include "TGuiFactory.h"
+#include "TInetAddress.h"
+#include "TInspectorImp.h"
+#include "TMacro.h"
+#include "TMathBase.h"
+#include "TMD5.h"
+#include "TMemberInspector.h"
+#include "TMessageHandler.h"
+#include "TNamed.h"
+#include "TNotifyLink.h"
+#include "TObject.h"
+#include "TObjectSpy.h"
+#include "TObjString.h"
+#include "TParameter.h"
+#include "TPluginManager.h"
+#include "TPoint.h"
+#include "TPRegexp.h"
+#include "TProcessID.h"
+#include "TProcessUUID.h"
+#include "TQClass.h"
+#include "TQCommand.h"
+#include "TQConnection.h"
+#include "TQObject.h"
+#include "TRedirectOutputGuard.h"
+#include "TRefCnt.h"
+#include "TRef.h"
+#include "TRegexp.h"
+#include "TRemoteObject.h"
+#include "TROOT.h"
+#include "TRootIOCtor.h"
+#include "TStopwatch.h"
+#include "TStorage.h"
+#include "TString.h"
+#include "TStringLong.h"
+#include "TStyle.h"
+#include "TSysEvtHandler.h"
+#include "TSystemDirectory.h"
+#include "TSystemFile.h"
+#include "TSystem.h"
+#include "TTask.h"
+#include "TThreadSlots.h"
+#include "TTime.h"
+#include "TTimer.h"
+#include "TTimeStamp.h"
+#include "TUri.h"
+#include "TUrl.h"
+#include "TUUID.h"
+#include "TVersionCheck.h"
+#include "TVirtualAuth.h"
+#include "TVirtualFFT.h"
+#include "TVirtualGL.h"
+#include "TVirtualMonitoring.h"
+#include "TVirtualMutex.h"
+#include "TVirtualPadEditor.h"
+#include "TVirtualPad.h"
+#include "TVirtualPadPainter.h"
+#include "TVirtualPerfStats.h"
+#include "TVirtualPS.h"
+#include "TVirtualQConnection.h"
+#include "TVirtualRWMutex.h"
+#include "TVirtualTableInterface.h"
+#include "TVirtualViewer3D.h"
+#include "TVirtualX.h"
+#include "ROOT/RLogger.hxx"
+#include "ROOT/RDrawable.hxx"
+#include "ROOT/RDirectoryEntry.hxx"
+#include "ROOT/RIndexIter.hxx"
+#include "strlcpy.h"
+#include "snprintf.h"
+#include "ROOT/TSeq.hxx"
+#include "TArrayC.h"
+#include "TArrayD.h"
+#include "TArrayF.h"
+#include "TArray.h"
+#include "TArrayI.h"
+#include "TArrayL64.h"
+#include "TArrayL.h"
+#include "TArrayS.h"
+#include "TBits.h"
+#include "TBtree.h"
+#include "TClassTable.h"
+#include "TClonesArray.h"
+#include "TCollection.h"
+#include "TCollectionProxyInfo.h"
+#include "TExMap.h"
+#include "THashList.h"
+#include "THashTable.h"
+#include "TIterator.h"
+#include "TList.h"
+#include "TMap.h"
+#include "TObjArray.h"
+#include "TObjectTable.h"
+#include "TOrdCollection.h"
+#include "TRefArray.h"
+#include "TRefTable.h"
+#include "TSeqCollection.h"
+#include "TSortedList.h"
+#include "TVirtualCollectionProxy.h"
+#include "ESTLType.h"
+#include "RStringView.h"
+#include "TClassEdit.h"
+#include "ROOT/RIntegerSequence.hxx"
+#include "ROOT/RMakeUnique.hxx"
+#include "ROOT/RNotFn.hxx"
+#include "ROOT/RSpan.hxx"
+#include "ROOT/RStringView.hxx"
+#include "ROOT/span.hxx"
+#include "ROOT/TypeTraits.hxx"
+#include "TUnixSystem.h"
+#include "root_std_complex.h"
+#include "TClingRuntime.h"
+#include "TBaseClass.h"
+#include "TClassGenerator.h"
+#include "TClass.h"
+#include "TClassMenuItem.h"
+#include "TClassRef.h"
+#include "TClassStreamer.h"
+#include "TDataMember.h"
+#include "TDataType.h"
+#include "TDictAttributeMap.h"
+#include "TDictionary.h"
+#include "TEnumConstant.h"
+#include "TEnum.h"
+#include "TFileMergeInfo.h"
+#include "TFunction.h"
+#include "TFunctionTemplate.h"
+#include "TGenericClassInfo.h"
+#include "TGlobal.h"
+#include "TInterpreter.h"
+#include "TInterpreterValue.h"
+#include "TIsAProxy.h"
+#include "TListOfDataMembers.h"
+#include "TListOfEnums.h"
+#include "TListOfEnumsWithLock.h"
+#include "TListOfFunctions.h"
+#include "TListOfFunctionTemplates.h"
+#include "TMemberStreamer.h"
+#include "TMethodArg.h"
+#include "TMethodCall.h"
+#include "TMethod.h"
+#include "TProtoClass.h"
+#include "TRealData.h"
+#include "TSchemaHelper.h"
+#include "TSchemaRule.h"
+#include "TSchemaRuleSet.h"
+#include "TStatusBitsChecker.h"
+#include "TStreamerElement.h"
+#include "TStreamer.h"
+#include "TToggleGroup.h"
+#include "TToggle.h"
+#include "TVirtualIsAProxy.h"
+#include "TVirtualRefProxy.h"
+#include "TVirtualStreamerInfo.h"
+#include "Getline.h"
 // Extra headers
 #include "ROOT/TSeq.hxx"
 #include "ROOT/StringConv.hxx"
