@@ -26,14 +26,12 @@ void lineWidth() {
 
       RPadPos pt(.3_normal, RPadLength::Normal(num));
       auto optts = canvas->Draw(RText(pt, std::to_string(i)));
-      optts->SetTextSize(13);
-      optts->SetTextAlign(32);
-      optts->SetTextFont(52);
+      optts->SetSize(13).SetAlign(32).SetFont(52);
 
       RPadPos pl1(.32_normal, RPadLength::Normal(num));
       RPadPos pl2(.8_normal , RPadLength::Normal(num));
       auto optls = canvas->Draw(RLine(pl1, pl2));
-      optls->SetLineWidth(i);
+      optls->SetWidth(i);
    }
 
    canvas->Show();
